@@ -1,5 +1,5 @@
 <?php if (!defined('PmWiki')) exit();
-/*  Copyright 2003-2005 Patrick R. Michaud (pmichaud@pobox.com)
+/*  Copyright 2003-2005, 2007 Patrick R. Michaud (pmichaud@pobox.com)
     This file is part of PmWiki; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +10,8 @@
     software authors when debugging PmWiki or other scripts.
 */
 
-ini_set('track_errors','1');
+@ini_set('display_errors', '1');
+@ini_set('track_errors','1');
 
 if ($action=='diag') {
   @session_start();
@@ -37,17 +38,16 @@ function HandleRuleset($pagename) {
   print Ruleset();
 }
 
-function DisplayStopWatch() {
+function StopWatchHTML($pagename, $print = 0) {
   global $StopWatch;
   StopWatch('now');
-  $out = "<pre>";
-  foreach((array)$StopWatch as $k => $x) {
-    $out .= "$x\n";
-  }
-  if (is_array($StopWatch)) array_pop($StopWatch);
+  $l = strlen(count($StopWatch));
+  $out = '<pre>';
+  foreach((array)$StopWatch as $i => $x)
+    $out .= sprintf("%{$l}d: %s\n", $i, $x);
   $out .= '</pre>';
+  if (is_array($StopWatch)) array_pop($StopWatch);
+  if ($print) print $out;
   return $out;
 }
 
-$FmtP['/\\$StopWatch/e'] = 'DisplayStopWatch()';
-
