@@ -1,5 +1,5 @@
 <?php if (!defined('PmWiki')) exit();
-/*  Copyright 2005-2010 Patrick R. Michaud (pmichaud@pobox.com)
+/*  Copyright 2005-2011 Patrick R. Michaud (pmichaud@pobox.com)
     This file is part of PmWiki; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2 of the License, or
@@ -29,7 +29,7 @@ if (isset($_GET['setprefs'])) {
   $sp = $_GET['setprefs'];
   setcookie($PrefsCookie, $sp, $PrefsCookieExpires, '/');
 }
-if ($sp && PageExists($sp)) XLPage('prefs', $sp);
+if ($sp && PageExists($sp)) XLPage('prefs', $sp, true);
 
 XLSDV('en', array(
   'ak_view' => '',
