@@ -1,5 +1,5 @@
 <?php if (!defined('PmWiki')) exit();
-/*  Copyright 2004-2010 Patrick R. Michaud (pmichaud@pobox.com)
+/*  Copyright 2004-2011 Patrick R. Michaud (pmichaud@pobox.com)
     This file is part of PmWiki; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2 of the License, or
@@ -24,20 +24,22 @@ SDV($EnableUploadOverwrite,1);
 SDVA($UploadExts,array(
   'gif' => 'image/gif', 'jpg' => 'image/jpeg', 'jpeg' => 'image/jpeg',
   'png' => 'image/png', 'bmp' => 'image/bmp', 'ico' => 'image/x-icon',
-  'wbmp' => 'image/vnd.wap.wbmp',
+  'wbmp'=> 'image/vnd.wap.wbmp', 'svg' => 'image/svg+xml', 'xcf' => 'image/x-xcf',
   'mp3' => 'audio/mpeg', 'au' => 'audio/basic', 'wav' => 'audio/x-wav',
+  'ogg' => 'audio/ogg', 'flac' => 'audio/x-flac',
+  'ogv' => 'video/ogg', 'mp4' => 'video/mp4', 'webm' => 'video/webm',
   'mpg' => 'video/mpeg', 'mpeg' => 'video/mpeg',
   'mov' => 'video/quicktime', 'qt' => 'video/quicktime',
   'wmf' => 'text/plain', 'avi' => 'video/x-msvideo',
   'zip' => 'application/zip', '7z' => 'application/x-7z-compressed',
-  'gz' => 'application/x-gzip', 'tgz' => 'application/x-gzip',
+  'gz'  => 'application/x-gzip', 'tgz' => 'application/x-gzip',
   'rpm' => 'application/x-rpm', 
   'hqx' => 'application/mac-binhex40', 'sit' => 'application/x-stuffit',
   'doc' => 'application/msword', 'ppt' => 'application/vnd.ms-powerpoint',
   'xls' => 'application/vnd.ms-excel', 'mdb' => 'text/plain',
   'exe' => 'application/octet-stream',
   'pdf' => 'application/pdf', 'psd' => 'text/plain', 
-  'ps' => 'application/postscript', 'ai' => 'application/postscript',
+  'ps'  => 'application/postscript', 'ai' => 'application/postscript',
   'eps' => 'application/postscript',
   'htm' => 'text/html', 'html' => 'text/html', 'css' => 'text/css', 
   'fla' => 'application/x-shockwave-flash', 
@@ -47,6 +49,8 @@ SDVA($UploadExts,array(
   'odt' => 'application/vnd.oasis.opendocument.text',
   'ods' => 'application/vnd.oasis.opendocument.spreadsheet',
   'odp' => 'application/vnd.oasis.opendocument.presentation',
+  'odg' => 'application/vnd.oasis.opendocument.graphics',
+  'epub'=> 'application/epub+zip',
   'kml' => 'application/vnd.google-earth.kml+xml',
   'kmz' => 'application/vnd.google-earth.kmz',
   '' => 'text/plain'));
@@ -208,7 +212,9 @@ function HandleDownload($pagename, $auth = 'read') {
 
 function HandlePostUpload($pagename, $auth = 'upload') {
   global $UploadVerifyFunction, $UploadFileFmt, $LastModFile, 
-    $EnableUploadVersions, $Now, $RecentUploadsFmt, $FmtV;
+    $EnableUploadVersions, $Now, $RecentUploadsFmt, $FmtV,
+    $NotifyItemUploadFmt, $NotifyItemFmt, $IsUploadPosted,
+    $UploadRedirectFunction;
   UploadAuth($pagename, $auth);
   $uploadfile = $_FILES['uploadfile'];
   $upname = $_REQUEST['upname'];
@@ -228,13 +234,19 @@ function HandlePostUpload($pagename, $auth = 'upload') {
     fixperms($filepath,0444);
     if ($LastModFile) { touch($LastModFile); fixperms($LastModFile); }
     $result = "upresult=success";
+    $FmtV['$upname'] = $upname;
+    $FmtV['$upsize'] = $uploadfile['size'];
     if (IsEnabled($RecentUploadsFmt, 0)) {
-      $FmtV['$upname'] = $upname;
-      $FmtV['$upsize'] = $uploadfile['size'];
       PostRecentChanges($pagename, '', '', $RecentUploadsFmt);
     }
+    if (IsEnabled($NotifyItemUploadFmt, 0) && function_exists('NotifyUpdate')) {
+      $NotifyItemFmt = $NotifyItemUploadFmt;
+      $IsUploadPosted = 1;
+      register_shutdown_function('NotifyUpdate', $pagename, getcwd());
+    }
   }
-  Redirect($pagename,"{\$PageUrl}?action=upload&uprname=$upname&$result");
+  SDV($UploadRedirectFunction, 'Redirect');
+  $UploadRedirectFunction($pagename,"{\$PageUrl}?action=upload&uprname=$upname&$result");
 }
 
 function UploadVerifyBasic($pagename,$uploadfile,$filepath) {
